proflevels.get: Get ILSA's proficiency levels

View source: R/proflevels.get.R

proflevels.getR Documentation

Get ILSA's proficiency levels

Description

Converts ILSA scores into proficiency levels.

Usage

proflevels.get(df, study = NULL, subject = NULL, combine = TRUE)

Arguments

df

a data frame.

study

an optional character vector indicating the subjects to be analyzed, for a list of available subjects, check ILSAinfo.

subject

an optional character vector indicating the subject for a list of available ILSA, check ILSAinfo.

combine

a logical value indicating if subjects should be combined in a single data frame.

Value

a data frame or a list.

Examples


data(timss99)

proflevels.get(timss99, subject = "math")


ILSAstats documentation built on March 13, 2026, 5:07 p.m.