leaguetable: ILSA's league tables

View source: R/leaguetable.R

leaguetableR Documentation

ILSA's league tables

Description

Estimates the mean score for all countries within a cycle of an ILSA. Arguments method, reps, and var, are extracted from ILSAinfo and can be overridden by the user.

Usage

leaguetable(
  df,
  study = NULL,
  year,
  subject = NULL,
  specification = NULL,
  addCI = TRUE,
  alpha = 0.05,
  method = NULL,
  reps = NULL,
  fixN = TRUE
)

Arguments

df

a data frame.

study

an optional character vector indicating the subjects to be analyzed, for a list of available subjects, check ILSAinfo.

year

a numeric vector indicating the ILSA name, for a list of available cycles, check ILSAinfo.

subject

an optional character vector indicating the subject for a list of available ILSA, check ILSAinfo.

specification

a character value indicating extra specification like grade (e.g., "G8" for TIMSS) or subject (e.g., "Math" for TIMSSADVANCED).

addCI

a logical value indicating if confidence intervals should be added. Defaults is TRUE.

alpha

a numeric value indicating confidence level.

method

a string indicating the name of the replication method. Available options are: "JK2-full", "JK2-half", "FAY-0.5", and "JK2-half-1PV".

Additionally, ILSA names can be used, defaulting into:

  • "TIMSS", "PIRLS", or "LANA" for "JK2-full";

  • "ICILS", "ICCS", or "CIVED" for "JK2-half";

  • "PISA" or "TALIS" for "FAY-0.5";

  • and "oldTIMSS", "oldPIRLS", or "RLII" for "JK2-half-1PV".

Note that "oldTIMSS" and "oldPIRLS" refer to the method used for TIMSS and PIRLS before 2015, where within imputation variance is estimated using only 1 plausible value.

reps

an integer indicating the number of replications to be created. If NULL the maximum number of zones will be used.

fixN

a logical value indicating if data should be "fixed" to meet official criteria. For example, reducing the sample for certain countries in TIMSS 1995. Default is TRUE.

Value

a data frame.

Examples

data(timss99)
leaguetable(df = timss99, year = 1999)


ILSAstats documentation built on March 13, 2026, 5:07 p.m.