| leaguetable | R Documentation |
Estimates the mean score for all countries within a cycle of an ILSA.
Arguments method, reps, and var, are extracted from
ILSAinfo and can be overridden by the user.
leaguetable(
df,
study = NULL,
year,
subject = NULL,
specification = NULL,
addCI = TRUE,
alpha = 0.05,
method = NULL,
reps = NULL,
fixN = TRUE
)
df |
a data frame. |
study |
an optional character vector indicating the subjects to be analyzed, for a list of available
subjects, check |
year |
a numeric vector indicating the ILSA name, for a list of available
cycles, check |
subject |
an optional character vector indicating the subject for a list of available
ILSA, check |
specification |
a character value indicating extra specification like grade
(e.g., |
addCI |
a logical value indicating if confidence intervals should be added.
Defaults is |
alpha |
a numeric value indicating confidence level. |
method |
a string indicating the name of the replication method.
Available options are:
Note that |
reps |
an integer indicating the number of replications to be created.
If |
fixN |
a logical value indicating if data should be "fixed" to meet official criteria.
For example, reducing the sample for certain countries in TIMSS 1995. Default is |
a data frame.
data(timss99)
leaguetable(df = timss99, year = 1999)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.