Estimates the mean score for all countries within a cycle of an ILSA.
Arguments method, reps, and var, are extracted from
autoILSA and can be overridden by the user.
leaguetable(
df,
study = NULL,
year,
subject = NULL,
specification = NULL,
addCI = TRUE,
alpha = 0.05,
method = NULL,
reps = NULL,
fixN = TRUE
)a data frame.
a data frame.
an optional character vector indicating the ILSA name, for a list of available
ILSA, check autoILSA. If NULL, the ILSA name will be determined
by the column names in the data frame.
a numeric vector indicating the ILSA name, for a list of available
cycles, check autoILSA.
an optional character vector indicating the subject for a list of available
ILSA, check autoILSA.
a character value indicating extra specification like grade
(e.g., "G8" for TIMSS) or subject (e.g., "Math" for TIMSSADVANCED).
a logical value indicating if confidence intervals should be added.
Defaults is TRUE.
a numeric value indicating confidence level.
a string indicating the name of the replication method.
Available options are:
"JK2-full", "JK2-half",
"FAY-0.5",
and "JK2-half-1PV".
Additionally, ILSA names can be used, defaulting into:
"TIMSS", "PIRLS", or "LANA" for "JK2-full";
"ICILS", "ICCS", or "CIVED" for "JK2-half";
"PISA" or "TALIS" for "FAY-0.5";
and "oldTIMSS", "oldPIRLS", or "RLII" for "JK2-half-1PV".
Note that "oldTIMSS" and "oldPIRLS"
refer to the method used for TIMSS and PIRLS before 2015,
where within imputation variance
is estimated using only 1 plausible value.
an integer indicating the number of replications to be created.
If NULL the maximum number of zones will be used.
a logical value indicating if data should be "fixed" to meet official criteria.
For example, reducing the sample for certain countries in TIMSS 1995. Default is TRUE.
data(timss99)
leaguetable(df = timss99, year = 1999)
Run the code above in your browser using DataLab