| prepILSA | R Documentation |
Modifies ILSA data to meet official participation cases, selects columns and transforms data into simple data frames converting missing values to NAs.
prepILSA(
df,
study = NULL,
year = NULL,
specification = NULL,
fixN = TRUE,
columns = NULL
)
df |
a data frame. |
study |
an optional character vector indicating the subjects to be analyzed, for a list of available
subjects, check |
year |
a numeric vector indicating the ILSA name, for a list of available
cycles, check |
specification |
a character value indicating extra specification like grade
(e.g., |
fixN |
a logical value indicating if data should be "fixed" to meet official criteria.
For example, reducing the sample for certain countries in TIMSS 1995. Default is |
columns |
a character vector indicating which columns should be selected.
If |
data(timss99)
head(timss99)
newdata <- prepILSA(df = timss99, columns = paste0("BSMMAT0",1:5),fixN = FALSE)
head(newdata)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.