proflevels: ILSA's proficiency levels

View source: R/proflevels.R

proflevelsR Documentation

ILSA's proficiency levels

Description

Estimates the proficiency levels for all countries within a cycle of an ILSA. Arguments method, and reps, are extracted from ILSAinfo and can be overridden by the user.

Usage

proflevels(
  df,
  study = NULL,
  year,
  subject = NULL,
  method = NULL,
  reps = NULL,
  type = c("long", "wide1", "wide2"),
  separateSE = TRUE,
  fixN = TRUE
)

Arguments

df

a data frame.

study

an optional character vector indicating the subjects to be analyzed, for a list of available subjects, check ILSAinfo.

year

a numeric vector indicating the ILSA name, for a list of available cycles, check ILSAinfo.

subject

an optional character vector indicating the subject for a list of available ILSA, check ILSAinfo.

method

a string indicating the name of the replication method. Available options are: "JK2-full", "JK2-half", "FAY-0.5", and "JK2-half-1PV".

Additionally, ILSA names can be used, defaulting into:

  • "TIMSS", "PIRLS", or "LANA" for "JK2-full";

  • "ICILS", "ICCS", or "CIVED" for "JK2-half";

  • "PISA" or "TALIS" for "FAY-0.5";

  • and "oldTIMSS", "oldPIRLS", or "RLII" for "JK2-half-1PV".

Note that "oldTIMSS" and "oldPIRLS" refer to the method used for TIMSS and PIRLS before 2015, where within imputation variance is estimated using only 1 plausible value.

reps

an integer indicating the number of replications to be created. If NULL the maximum number of zones will be used.

type

a character value indicating the type of table to produce. Options include: "long", for a long table with a column with the proportions and another one for the standard error; "wide1" for a wide table where groups are distributed in lines; "wide2" for a wide table where groups are distributed in columns.

separateSE

a logical value indicating if standard errors should be separated from proportions, each as an element from a list. Only works for wide tables. Default is TRUE.

fixN

a logical value indicating if data should be "fixed" to meet official criteria. For example, reducing the sample for certain countries in TIMSS 1995. Default is TRUE.

Value

a data frame or a list.

Examples

data(timss99)

proflevels(timss99,year = 1999,type = "long",subject = "math")


ILSAstats documentation built on March 13, 2026, 5:07 p.m.