| proflevels | R Documentation |
Estimates the proficiency levels for all countries within a cycle of an ILSA.
Arguments method, and reps, are extracted from
ILSAinfo and can be overridden by the user.
proflevels(
df,
study = NULL,
year,
subject = NULL,
method = NULL,
reps = NULL,
type = c("long", "wide1", "wide2"),
separateSE = TRUE,
fixN = TRUE
)
df |
a data frame. |
study |
an optional character vector indicating the subjects to be analyzed, for a list of available
subjects, check |
year |
a numeric vector indicating the ILSA name, for a list of available
cycles, check |
subject |
an optional character vector indicating the subject for a list of available
ILSA, check |
method |
a string indicating the name of the replication method.
Available options are:
Note that |
reps |
an integer indicating the number of replications to be created.
If |
type |
a character value indicating the type of table to produce.
Options include: |
separateSE |
a logical value indicating if standard errors should be separated from
proportions, each as an element from a list. Only works for wide tables. Default is |
fixN |
a logical value indicating if data should be "fixed" to meet official criteria.
For example, reducing the sample for certain countries in TIMSS 1995. Default is |
a data frame or a list.
data(timss99)
proflevels(timss99,year = 1999,type = "long",subject = "math")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.