Estimates the proficiency levels for all countries within a cycle of an ILSA.
Arguments method, and reps, are extracted from
autoILSA and can be overridden by the user.
proflevels(
df,
study = NULL,
year,
subject = NULL,
method = NULL,
reps = NULL,
type = c("long", "wide1", "wide2"),
separateSE = TRUE,
fixN = TRUE,
accumulated = FALSE
)a data frame or a list.
a data frame.
an optional character vector indicating the ILSA name, for a list of available
ILSA, check autoILSA. If NULL, the ILSA name will be determined
by the column names in the data frame.
a numeric vector indicating the ILSA name, for a list of available
cycles, check autoILSA.
an optional character vector indicating the subject for a list of available
ILSA, check autoILSA.
a string indicating the name of the replication method.
Available options are:
"JK2-full", "JK2-half",
"FAY-0.5",
and "JK2-half-1PV".
Additionally, ILSA names can be used, defaulting into:
"TIMSS", "PIRLS", or "LANA" for "JK2-full";
"ICILS", "ICCS", or "CIVED" for "JK2-half";
"PISA" or "TALIS" for "FAY-0.5";
and "oldTIMSS", "oldPIRLS", or "RLII" for "JK2-half-1PV".
Note that "oldTIMSS" and "oldPIRLS"
refer to the method used for TIMSS and PIRLS before 2015,
where within imputation variance
is estimated using only 1 plausible value.
an integer indicating the number of replications to be created.
If NULL the maximum number of zones will be used.
a character value indicating the type of table to produce.
Options include: "long", for a long table with a column with the proportions
and another one for the standard error; "wide1" for a wide table where groups
are distributed in lines; "wide2" for a wide table where groups are distributed in columns.
a logical value indicating if standard errors should be separated from
proportions, each as an element from a list. Only works for wide tables. Default is TRUE.
a logical value indicating if data should be "fixed" to meet official criteria.
For example, reducing the sample for certain countries in TIMSS 1995. Default is TRUE.
a logical value indicating if proficiency levels should be accumulated.
data(timss99)
proflevels(timss99,year = 1999,type = "long",subject = "math")
Run the code above in your browser using DataLab