View source: R/proflevels.get.R
| proflevels.get | R Documentation |
Converts ILSA scores into proficiency levels.
proflevels.get(df, study = NULL, subject = NULL, combine = TRUE)
df |
a data frame. |
study |
an optional character vector indicating the subjects to be analyzed, for a list of available
subjects, check |
subject |
an optional character vector indicating the subject for a list of available
ILSA, check |
combine |
a logical value indicating if subjects should be combined in a single data frame. |
a data frame or a list.
data(timss99)
proflevels.get(timss99, subject = "math")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.