Learn R Programming

ILSAstats (version 0.4.5)

proflevels.get: Get ILSA's proficiency levels

Description

Converts ILSA scores into proficiency levels.

Usage

proflevels.get(df, study = NULL, subject = NULL, combine = TRUE)

Value

a data frame or a list.

Arguments

df

a data frame.

study

an optional character vector indicating the ILSA name, for a list of available ILSA, check autoILSA. If NULL, the ILSA name will be determined by the column names in the data frame.

subject

an optional character vector indicating the subject for a list of available ILSA, check autoILSA.

combine

a logical value indicating if subjects should be combined in a single data frame.

Examples

Run this code

data(timss99)

proflevels.get(timss99, subject = "math")

Run the code above in your browser using DataLab