View source: R/repprop.table.R
| repprop.table | R Documentation |
Creates tables for proportions using replicate weights for a variable or a group of plausible values variables and for one or more populations.
repprop.table(x, type = c("long", "wide1", "wide2"), separateSE = TRUE)
x |
a list produced by |
type |
a character value indicating the type of table to produce.
Options include: |
separateSE |
a logical value indicating if standard errors should be separated from
proportions, each as an element from a list. Only works for wide tables. Default is |
a adata frame or a list.
# Creation of replicate weights
RW <- repcreate(df = repdata, # the data frame with all the information
wt = "wt", # the total weights column name
jkzone = "jkzones", # the jkzones column name
jkrep = "jkrep", # the jkreps column name
repwtname = "REPWT", # the desired name for the rep weights
reps = 50, # the number of replications
method = "ICILS") # the name of the method aka the study name
x = repprop(x = c("item01"),
group = "GROUP",
repwt = "REPWT", wt = "wt", df = cbind(repdata,RW),
method = "ICILS")
repprop.table(x, type = "long")
repprop.table(x, type = "wide1", separateSE = TRUE)
repprop.table(x, type = "wide1", separateSE = FALSE)
repprop.table(x, type = "wide2", separateSE = TRUE)
repprop.table(x, type = "wide2", separateSE = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.